git.lucas.co / go_mono
git clone https://git.lucas.co/go_mono.git

commitb3d8467d91f6ab3c9240e1c1e98309baf9ba6343
parent00f88f596f
authorNigel Tao <[email protected]>
date2015-09-01 15:04
font: fix up some old x/exp/shiny references.

Also add canonical import paths for the newly merged packages.

Change-Id: I96fe3a964ba08e718fc9163c980ef7ea9da551fe
Reviewed-on: https://go-review.googlesource.com/14148
Reviewed-by: David Symonds <[email protected]>

 example/font/main.go           | 6 +++---
 font/font.go                   | 4 +---
 font/plan9font/example_test.go | 4 ++--
 font/plan9font/plan9font.go    | 4 ++--
 4 files changed, 8 insertions(+), 10 deletions(-)

diff --git a/font/font.go b/font/font.go
index a9b9729..9cf43ff 100644
--- a/font/font.go
+++ b/font/font.go
@@ -7,9 +7,7 @@
 //
 // Other packages provide font face implementations. For example, a truetype
 // package would provide one based on .ttf font files.
-package font
-
-// TODO: move this from golang.org/x/exp to golang.org/x/image ??
+package font // import "golang.org/x/image/font"
 
 import (
 	"image"
diff --git a/font/plan9font/example_test.go b/font/plan9font/example_test.go
index 071fcfa..c1eacb2 100644
--- a/font/plan9font/example_test.go
+++ b/font/plan9font/example_test.go
@@ -13,8 +13,8 @@ import (
 	"path"
 	"path/filepath"
 
-	"golang.org/x/exp/shiny/font"
-	"golang.org/x/exp/shiny/font/plan9font"
+	"golang.org/x/image/font"
+	"golang.org/x/image/font/plan9font"
 	"golang.org/x/image/math/fixed"
 )
 
diff --git a/font/plan9font/plan9font.go b/font/plan9font/plan9font.go
index 89f0a2d..da56ee8 100644
--- a/font/plan9font/plan9font.go
+++ b/font/plan9font/plan9font.go
@@ -5,7 +5,7 @@
 // Package plan9font implements font faces for the Plan 9 font and subfont file
 // formats. These formats are described at
 // http://plan9.bell-labs.com/magic/man2html/6/font
-package plan9font
+package plan9font // import "golang.org/x/image/font/plan9font"
 
 // TODO: have a subface use an *image.Alpha instead of plan9Image implementing
 // the image.Image interface? The image/draw code has a fast path for
@@ -21,7 +21,7 @@ import (
 	"strconv"
 	"strings"
 
-	"golang.org/x/exp/shiny/font"
+	"golang.org/x/image/font"
 	"golang.org/x/image/math/fixed"
 )
diff --git a/example/font/main.go b/example/font/main.go
index 10909f4..81aaf3f 100644
--- a/example/font/main.go
+++ b/example/font/main.go
@@ -4,7 +4,7 @@
 
 // +build ignore
 //
 // This build tag means that "go install golang.org/x/exp/shiny/..." doesn't
 // install this example program. Use "go run main.go" to run it.
 
 // Font is a basic example of using fonts.
@@ -22,8 +22,8 @@ import (
 	"path/filepath"
 	"strings"
 
-	"golang.org/x/exp/shiny/font"
-	"golang.org/x/exp/shiny/font/plan9font"
+	"golang.org/x/image/font"
+	"golang.org/x/image/font/plan9font"
 	"golang.org/x/image/math/fixed"
 )
 
@@ -4,7 +4,7 @@
 // +build ignore
 //
-// This build tag means that "go install golang.org/x/exp/shiny/..." doesn't
+// This build tag means that "go install golang.org/x/image/..." doesn't
 // install this example program. Use "go run main.go" to run it.
 